package com.blazinggames.retro.modern.search;

// Spelchan imports
import com.blazinggames.urcl.URCLApplet;
import com.blazinggames.urcl.ui.*;

// Retro imports
import com.blazinggames.retro.modern.Title;

/**
 * Ultimate Retro Project Episode 10: Modern Tank Battle
 * Copyright (C) 2001, 2004, 2006 Blazing Games Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * @author Billy D. Spelchan
 * @version 1.10.060203

*/
public class ModernTankApplet
extends URCLApplet
{
    // *********************
    // ***** CONSTANTS *****
    // *********************

    private static final String VERSION =  "1.10.060203";
    private static final String NAME = "Modern Tanks";
    private static final String COPYRIGHT = "Copyright "+(char)169+"  2001,2004,2006 Blazing Games Inc. All Rights Reserved.";

    TankDisplay _game;

    protected void initDisplays()
    {
        System.out.println(NAME + " Version " + VERSION);
        System.out.println(COPYRIGHT);
        _titleDisplay = new TankTitle("10");
        _titleDisplay.initialize(this);
        _game = new TankDisplay();
        _game.initialize(this);
    }

    public String getAppletInfo()
    {
        return NAME + " version " + VERSION +" " + COPYRIGHT;
    }

    public void displayEvent(Display caller, String command)
    {
        super.displayEvent(caller, command);

        if (command.startsWith("TANK_START"))
        {
            TankTitle tt = (TankTitle)_titleDisplay;
            // querry TankTitle class for settings and set them
            for (int cntr = 0; cntr < 8; ++cntr)
            {
                _game.setPlayerType(cntr, tt.getPlayerType(cntr));
            }
            _game.setExplosionRadius(tt.getExplosionRadius());
            _game.startGame();
            showDisplay(2);
        }
        else if (command.startsWith("TANK_TITLE"))
        {
            showDisplay(1);
        }
    }

    /**
        * Handles switching the game screen to the indicated display ID.
     * Currently they are set up as follows:
     * <UL>
     * <LI>0 - Error screen</LI>
     * <LI>1 - Title Screen</LI>
     * <LI>2 - Artillery Game Screen</LI>
     * </LI>
     *
     * @param id ID of display to switch to
     * @return the indicated display
     */
    protected Display getDisplay(int id)
    {
        if (id == 2)
            return _game;
        else
            return super.getDisplay(id);
    }

    public String getName()
    {
        return NAME;
    }
}
