package com.blazinggames.urcl.ui.comp;

// Java imports
import java.awt.*;

// Blazing Games imports
import com.blazinggames.urcl.ui.sprite.ImageStripSprite;

/**
 * Ultimate Retro Common Library
 * Copyright (C) 2001, 2003-2004 Blazing Games Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * ------------------------------------------------
 * 
 * A multistate toggle button. The toggle bases it's
 * display on an indicated image, which it uses as a horizontal image strip.
 * The first image is the disabled image, with subsequent images used for each
 * of the states.
 * 
 * @author Billy D. Spelchan
 * @version OSR1.00
 */
public class Toggle
extends Comp
{
    // *********************
    // ***** VARIABLES *****
    // *********************

    private int _maxStates;
    private int _state;


    // ************************
    // ***** CONSTRUCTORS *****
    // ************************

    public Toggle(Component c, Image i, int x, int y, int w, int h, int states)
    {
        super();
        setBounds(x, y, w, h);
        _sprite = new ImageStripSprite(c, i, w, h);
        ((ImageStripSprite)_sprite).setFrame(1);
        _state = 0;
        _maxStates = states;
    }

    // *******************************
    // ***** METHODS - From Comp *****
    // *******************************

    /**
        * Called when mouse button has been released.
     *
     * @param x x coordinate of where mouse was released
     * @param y y coordinate of where mouse was released
     * @return true if component clicked (pressed and released in component)
     */
    public boolean mouse_up(int x, int y)
    {
        boolean b = super.mouse_up(x, y);

        if ( (b) && (_state >= 0) )
        {
            setState(_state+1);
        }

        return b;
    }

    /**
        * Sets if a component is active or not. A non-active component generally
     * looks different and doesn't respond to events.
     *
     * @param b true if component is to be active, false otherwise
     */
    public void setActive(boolean b)
    {
        super.setActive(b);

        if ( (b) && (_state < 0) )
            _state = 0;
        else if (b == false)
            _state = -1;

        if (_sprite != null)
        {
            ((ImageStripSprite)_sprite).setFrame(_state + 1);
        }
    }

    // *****************************************************
    // ***** METHODS - Information getting and setting *****
    // *****************************************************

    /**
        * Changes the state of the toggle to the indicated state.
     *
     * @param n new state for the component
     */
    public void setState(int n)
    {
        if (_isActive == false)
            return;
        if (n >= _maxStates)
        {
            _state = 0;
        }
        else
        {
            _state = n;
        }

        if (_sprite != null)
        {
            ((ImageStripSprite)_sprite).setFrame(_state + 1);
        }
    }

    /**
        * Goes to the next state in the toggle sequence
     */
    public void nextState()
    {
        setState(_state+1);
    }

    /**
        * @return Current state of the toggle (-1 if disabled)
     */
    public int getState()
    {
        return _state;
    }

    /**
        * Sets the image that the sprite uses
     *
     */
    public void setImage(Component c, Image i)
    {
        _sprite = new ImageStripSprite(c, i, _bounds.width, _bounds.height);
    }
}
